#ifndef NT2_INCLUDE_FUNCTIONS_NTHROOT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NTHROOT_HPP_INCLUDED

#include <nt2/exponential/include/functions/nthroot.hpp>

#endif
